@@ -19,8 +19,12 @@
 
 from __future__ import print_function, unicode_literals
 
-import os, unittest, json, tempfile, shutil, pipes
-
+import os
+import unittest
+import json
+import tempfile
+import shutil
+import pipes
 import dxpy
 from dxpy_testutil import DXTestCase, check_output, temporary_project
 import dxpy_testutil as testutil
@@ -108,8 +112,33 @@ def update_environ(**kwargs):
             output[k] = v
     return output
 
+
+@unittest.skipUnless(testutil.TEST_RUN_JOBS, 'skipping tests that would run jobs')
 class TestDXBashHelpers(DXTestCase):
-    @unittest.skipUnless(testutil.TEST_RUN_JOBS, 'skipping tests that would run jobs')
+    def test_vars(self):
+        '''  Quick test for the bash variables '''
+        with temporary_project('TestDXBashHelpers.test_app1 temporary project') as p:
+            env = update_environ(DX_PROJECT_CONTEXT_ID=p.get_id())
+
+            # Upload some files for use by the applet
+            dxpy.upload_string("1234\n", project=p.get_id(), name="A.txt")
+
+            # Build the applet, patching in the bash helpers from the
+            # local checkout
+            applet_id = build_app_with_bash_helpers(os.path.join(TEST_APPS, 'vars'), p.get_id())
+
+            # Run the applet
+            applet_args = ['-iseq1=A.txt', '-iseq2=A.txt', '-igenes=A.txt', '-igenes=A.txt',
+                           '-ii=5', '-ix=4.2', '-ib=true', '-is=hello',
+                           '-iil=6', '-iil=7', '-iil=8',
+                           '-ixl=3.3', '-ixl=4.4', '-ixl=5.0',
+                           '-ibl=true', '-ibl=false', '-ibl=true',
+                           '-isl=hello', '-isl=world', '-isl=next',
+                           '-imisc={"hello": "world", "foo": true}']
+            cmd_args = ['dx', 'run', '--yes', '--watch', applet_id]
+            cmd_args.extend(applet_args)
+            run(cmd_args, env=env)
+
     def test_basic(self):
         with temporary_project('TestDXBashHelpers.test_app1 temporary project') as dxproj:
             env = update_environ(DX_PROJECT_CONTEXT_ID=dxproj.get_id())
@@ -128,7 +157,6 @@ class TestDXBashHelpers(DXTestCase):
             cmd_args.extend(applet_args)
             run(cmd_args, env=env)
 
-    @unittest.skipUnless(testutil.TEST_RUN_JOBS, 'skipping tests that would run jobs')
     def test_sub_jobs(self):
         '''  Tests a bash script that generates sub-jobs '''
         with temporary_project('TestDXBashHelpers.test_app1 temporary project') as dxproj:
@@ -199,7 +227,6 @@ class TestDXBashHelpers(DXTestCase):
             check_file_content('first_file', 'first_file.txt', "f1.txt", "contents of first_file")
             check_file_content('final_file', 'final_file.txt', "f2.txt", "1234ABCD")
 
-    @unittest.skipUnless(testutil.TEST_RUN_JOBS, 'skipping tests that would run jobs')
     def test_parseq(self):
         ''' Tests the parallel/sequential variations '''
         with temporary_project('TestDXBashHelpers.test_app1 temporary project') as dxproj:
@@ -219,7 +246,34 @@ class TestDXBashHelpers(DXTestCase):
             cmd_args.extend(applet_args)
             run(cmd_args, env=env)
 
-    @unittest.skipUnless(testutil.TEST_RUN_JOBS, 'skipping tests that would run jobs')
+    def test_prefix_patterns(self):
+        """ Tests that the bash prefix variable works correctly, and
+        respects patterns.
+        """
+        with temporary_project('TestDXBashHelpers.test_app1 temporary project') as dxproj:
+            env = update_environ(DX_PROJECT_CONTEXT_ID=dxproj.get_id())
+            filenames = ["A.bar", "A.json.dot.bar", "A.vcf.pam", "A.foo.bar",
+                         "fooxxx.bam", "A.bar.gz", "x13year23.sam"]
+            for fname in filenames:
+                dxpy.upload_string("1234", project=dxproj.get_id(), name=fname)
+
+            # Build the applet, patching in the bash helpers from the
+            # local checkout
+            applet_id = build_app_with_bash_helpers(os.path.join(TEST_APPS, 'prefix_patterns'), dxproj.get_id())
+
+            # Run the applet
+            applet_args = ['-iseq1=A.bar',
+                           '-iseq2=A.json.dot.bar',
+                           '-igene=A.vcf.pam',
+                           '-imap=A.foo.bar',
+                           '-imap2=fooxxx.bam',
+                           '-imap3=A.bar',
+                           '-imap4=A.bar.gz',
+                           '-imulti=x13year23.sam']
+            cmd_args = ['dx', 'run', '--yes', '--watch', applet_id]
+            cmd_args.extend(applet_args)
+            run(cmd_args, env=env)
+
     def test_deepdirs(self):
         ''' Tests the use of subdirectories in the output directory '''
         def check_output_key(job_output, out_param_name, num_files, dxproj):
@@ -275,6 +329,9 @@ class TestDXBashHelpers(DXTestCase):
             verify_files_in_dir("/foo/bar", ["luke.txt"], dxproj)
             verify_files_in_dir("/", ["A.txt", "B.txt", "C.txt", "num_chrom.txt"], dxproj)
 
+
+@unittest.skipUnless(testutil.TEST_RUN_JOBS and testutil.TEST_BENCHMARKS,
+                     'skipping tests that would run jobs, or, run benchmarks')
 class TestDXBashHelpersBenchmark(DXTestCase):
 
     def create_file_of_size(self, fname, size_bytes):
@@ -307,23 +364,18 @@ class TestDXBashHelpersBenchmark(DXTestCase):
             cmd_args.extend(flag_list)
             run(cmd_args, env=env)
 
-    @unittest.skipUnless(testutil.TEST_BENCHMARKS, 'skipping tests that run benchmarks')
     def test_seq(self):
         self.run_applet_with_flags(["-iparallel=false"], 40, 1024 * 1024)
 
-    @unittest.skipUnless(testutil.TEST_BENCHMARKS, 'skipping tests that run benchmarks')
     def test_par(self):
         self.run_applet_with_flags(["-iparallel=true"], 40, 1024 * 1024)
 
-    @unittest.skipUnless(testutil.TEST_BENCHMARKS, 'skipping tests that run benchmarks')
     def test_seq_100m(self):
         self.run_applet_with_flags(["-iparallel=false"], 40, 100 * 1024 * 1024)
 
-    @unittest.skipUnless(testutil.TEST_BENCHMARKS, 'skipping tests that run benchmarks')
     def test_par_100m(self):
         self.run_applet_with_flags(["-iparallel=true"], 40, 100 * 1024 * 1024)
 
-    @unittest.skipUnless(testutil.TEST_BENCHMARKS, 'skipping tests that run benchmarks')
     def test_par_1g(self):
         self.run_applet_with_flags(["-iparallel=true"], 10, 1024 * 1024 * 1024)
 
